@@ -2,9 +2,10 @@
 from pydantic import Field
 
 from oteapi.models.genericconfig import GenericConfig
+from oteapi.models.secretconfig import SecretConfig
 
 
-class FunctionConfig(GenericConfig):
+class FunctionConfig(GenericConfig, SecretConfig):
     """Function Strategy Data Configuration."""
 
     functionType: str = Field(
