@@ -62,7 +62,11 @@ class HTTPSStrategy:
         if cache.config.accessKey and cache.config.accessKey in cache:
             key = cache.config.accessKey
         else:
-            req = requests.get(self.download_config.downloadUrl, allow_redirects=True)
+            req = requests.get(
+                self.download_config.downloadUrl,
+                allow_redirects=True,
+                timeout=(3, 27),  # timeout: (connect, read) in seconds
+            )
             key = cache.add(req.content)
 
         return SessionUpdateHTTPS(key=key)
