@@ -9,7 +9,6 @@ from pydantic.dataclasses import dataclass
 
 from oteapi.datacache import DataCache
 from oteapi.models import AttrDict, DataCacheConfig, ResourceConfig, SessionUpdate
-from oteapi.plugins import create_strategy
 
 if TYPE_CHECKING:  # pragma: no cover
     from typing import Any, Iterable
@@ -174,13 +173,11 @@ class XLSXParseStrategy:
             A dict with column-name/column-value pairs. The values are lists.
 
         """
-        download_config = ResourceConfig(**self.parse_config.dict())
-        download_config.configuration = self.parse_config.configuration.download_config
-        downloader = create_strategy("download", download_config)
-        output = downloader.get()
 
         cache = DataCache(self.parse_config.configuration.datacache_config)
-        with cache.getfile(key=output["key"], suffix=".xlsx") as filename:
+        if session is None:
+            raise ValueError("Missing session")
+        with cache.getfile(key=session["key"], suffix=".xlsx") as filename:
             # Note that we have to set read_only=False to ensure that
             # load_workbook() properly closes the xlsx file after reading.
             # Otherwise Windows will fail when the temporary file is removed
